/*
Copyright (c) 2019-2022 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Kasim Baybikov, <kmbaybikov@basistech.ru>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package provider

import (
	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/account"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/audit"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/bservice"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/disks"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/dpdknet"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/extnet"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/flipgroup"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/image"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/k8s"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/kvmvm"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/lb"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/locations"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/rg"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/snapshot"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/stack"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/vfpool"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/vins"

	cb_account "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/account"
	cb_audit "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/audit"
	cb_disks "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/disks"
	cb_dpdknet "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/dpdknet"
	cb_extnet "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/extnet"
	cb_flipgroup "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/flipgroup"
	cb_grid "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/grid"
	cb_image "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/image"
	cb_k8ci "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/k8ci"
	cb_k8s "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/k8s"
	cb_kvmvm "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/kvmvm"
	cb_lb "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/lb"
	cb_node "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/node"
	cb_pcidevice "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/pcidevice"
	cb_rg "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/rg"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/sep"
	cb_sep "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/sep"
	cb_stack "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/stack"
	cb_user "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/user"
	cb_vfpool "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/vfpool"
	cb_vins "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/vins"
	// cb_vgpu "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/vgpu"
)

func newDataSourcesMap() map[string]*schema.Resource {
	return map[string]*schema.Resource{
		"decort_account":                           account.DataSourceAccount(),
		"decort_audit":                             audit.DataSourceAudit(),
		"decort_resgroup":                          rg.DataSourceResgroup(),
		"decort_kvmvm":                             kvmvm.DataSourceCompute(),
		"decort_kvmvm_list":                        kvmvm.DataSourceComputeList(),
		"decort_kvmvm_audits":                      kvmvm.DataSourceComputeAudits(),
		"decort_kvmvm_get_audits":                  kvmvm.DataSourceComputeGetAudits(),
		"decort_kvmvm_get_console_url":             kvmvm.DataSourceComputeGetConsoleUrl(),
		"decort_kvmvm_get_log":                     kvmvm.DataSourceComputeGetLog(),
		"decort_kvmvm_pfw_list":                    kvmvm.DataSourceComputePfwList(),
		"decort_kvmvm_user_list":                   kvmvm.DataSourceComputeUserList(),
		"decort_kvmvm_snapshot_usage":              kvmvm.DataSourceComputeSnapshotUsage(),
		"decort_k8s":                               k8s.DataSourceK8s(),
		"decort_k8s_list":                          k8s.DataSourceK8sList(),
		"decort_k8s_list_deleted":                  k8s.DataSourceK8sListDeleted(),
		"decort_k8s_wg":                            k8s.DataSourceK8sWg(),
		"decort_k8s_wg_list":                       k8s.DataSourceK8sWgList(),
		"decort_k8s_computes":                      k8s.DataSourceK8sComputes(),
		"decort_k8ci_list":                         k8s.DataSourceK8CIList(),
		"decort_vins":                              vins.DataSourceVins(),
		"decort_vins_list":                         vins.DataSourceVinsList(),
		"decort_vins_audits":                       vins.DataSourceVinsAudits(),
		"decort_vins_ip_list":                      vins.DataSourceVinsIpList(),
		"decort_vins_list_deleted":                 vins.DataSourceVinsListDeleted(),
		"decort_vins_ext_net_list":                 vins.DataSourceVinsExtNetList(),
		"decort_vins_nat_rule_list":                vins.DataSourceVinsNatRuleList(),
		"decort_vins_static_route_list":            vins.DataSourceStaticRouteList(),
		"decort_vins_static_route":                 vins.DataSourceStaticRoute(),
		"decort_snapshot_list":                     snapshot.DataSourceSnapshotList(),
		"decort_disk":                              disks.DataSourceDisk(),
		"decort_disk_list":                         disks.DataSourceDiskList(),
		"decort_rg_list":                           rg.DataSourceRgList(),
		"decort_rg_affinity_group_computes":        rg.DataSourceRgAffinityGroupComputes(),
		"decort_rg_affinity_groups_list":           rg.DataSourceRgAffinityGroupsList(),
		"decort_rg_affinity_groups_get":            rg.DataSourceRgAffinityGroupsGet(),
		"decort_rg_audits":                         rg.DataSourceRgAudits(),
		"decort_rg_list_computes":                  rg.DataSourceRgListComputes(),
		"decort_rg_list_deleted":                   rg.DataSourceRgListDeleted(),
		"decort_rg_list_lb":                        rg.DataSourceRgListLb(),
		"decort_rg_list_pfw":                       rg.DataSourceRgListPfw(),
		"decort_rg_list_vins":                      rg.DataSourceRgListVins(),
		"decort_rg_usage":                          rg.DataSourceRgUsage(),
		"decort_disk_list_types_detailed":          disks.DataSourceDiskListTypesDetailed(),
		"decort_disk_list_types":                   disks.DataSourceDiskListTypes(),
		"decort_disk_list_deleted":                 disks.DataSourceDiskListDeleted(),
		"decort_disk_list_unattached":              disks.DataSourceDiskListUnattached(),
		"decort_disk_snapshot":                     disks.DataSourceDiskSnapshot(),
		"decort_disk_snapshot_list":                disks.DataSourceDiskSnapshotList(),
		"decort_disk_replication":                  disks.DataSourceDiskReplication(),
		"decort_account_list":                      account.DataSourceAccountList(),
		"decort_account_computes_list":             account.DataSourceAccountComputesList(),
		"decort_account_disks_list":                account.DataSourceAccountDisksList(),
		"decort_account_vins_list":                 account.DataSourceAccountVinsList(),
		"decort_account_audits_list":               account.DataSourceAccountAuditsList(),
		"decort_account_rg_list":                   account.DataSourceAccountRGList(),
		"decort_account_consumed_units":            account.DataSourceAccountConsumedUnits(),
		"decort_account_consumed_units_by_type":    account.DataSourceAccountConsumedUnitsByType(),
		"decort_account_reserved_units":            account.DataSourceAccountReservedUnits(),
		"decort_account_templates_list":            account.DataSourceAccountTemplatessList(),
		"decort_account_deleted_list":              account.DataSourceAccountDeletedList(),
		"decort_account_flipgroups_list":           account.DataSourceAccountFlipGroupsList(),
		"decort_bservice_list":                     bservice.DataSourceBasicServiceList(),
		"decort_bservice":                          bservice.DataSourceBasicService(),
		"decort_bservice_snapshot_list":            bservice.DataSourceBasicServiceSnapshotList(),
		"decort_bservice_group":                    bservice.DataSourceBasicServiceGroup(),
		"decort_bservice_deleted_list":             bservice.DataSourceBasicServiceDeletedList(),
		"decort_dpdknet":                           dpdknet.DataSourceDPDKNet(),
		"decort_dpdknet_list":                      dpdknet.DataSourceDPDKNetList(),
		"decort_extnet_list":                       extnet.DataSourceExtnetList(),
		"decort_extnet_computes_list":              extnet.DataSourceExtnetComputesList(),
		"decort_extnet":                            extnet.DataSourceExtnet(),
		"decort_extnet_default":                    extnet.DataSourceExtnetDefault(),
		"decort_extnet_reserved_ip_list":           extnet.DataSourceExtnetReservedIp(),
		"decort_locations_list":                    locations.DataSourceLocationsList(),
		"decort_location_url":                      locations.DataSourceLocationUrl(),
		"decort_image_list":                        image.DataSourceImageList(),
		"decort_image":                             image.DataSourceImage(),
		"decort_lb":                                lb.DataSourceLB(),
		"decort_lb_list":                           lb.DataSourceLBList(),
		"decort_lb_list_deleted":                   lb.DataSourceLBListDeleted(),
		"decort_flipgroup":                         flipgroup.DataSourceFlipgroup(),
		"decort_flipgroup_list":                    flipgroup.DataSourceFlipGroupList(),
		"decort_stack":                             stack.DataSourceStack(),
		"decort_stack_list":                        stack.DataSourceStackList(),
		"decort_vfpool":                            vfpool.DataSourceVFPool(),
		"decort_vfpool_list":                       vfpool.DataSourceVFPoolList(),
		"decort_account_resource_consumption_list": account.DataSourceAccountResourceConsumptionList(),
		"decort_account_resource_consumption_get":  account.DataSourceAccountResourceConsumptionGet(),
		"decort_kvmvm_list_deleted":                kvmvm.DataSourceComputeListDeleted(),
		"decort_kvmvm_vgpu_list":                   kvmvm.DataSourceComputeVGPUList(),
		"decort_kvmvm_pci_device_list":             kvmvm.DataSourceComputePCIDeviceList(),
		"decort_k8s_wg_cloud_init":                 k8s.DataSourceK8sWgCloudInit(),
		"decort_rg_resource_consumption_list":      rg.DataSourceRGResourceConsumptionList(),
		"decort_rg_resource_consumption_get":       rg.DataSourceRGResourceConsumptionGet(),
		"decort_sep_and_pools_available_list":      sep.DataSourceAvailableSEPAndPoolsList(),

		"decort_cb_account":                           cb_account.DataSourceAccount(),
		"decort_cb_account_list":                      cb_account.DataSourceAccountList(),
		"decort_cb_account_computes_list":             cb_account.DataSourceAccountComputesList(),
		"decort_cb_account_list_deleted":              cb_account.DataSourceAccountDeletedList(),
		"decort_cb_account_disks_list":                cb_account.DataSourceAccountDisksList(),
		"decort_cb_account_flipgroups_list":           cb_account.DataSourceAccountFlipGroupsList(),
		"decort_cb_account_rg_list":                   cb_account.DataSourceAccountRGList(),
		"decort_cb_account_vins_list":                 cb_account.DataSourceAccountVinsList(),
		"decort_cb_account_resource_consumption_get":  cb_account.DataSourceAccountResourceConsumptionGet(),
		"decort_cb_account_resource_consumption_list": cb_account.DataSourceAccountResourceConsumptionList(),
		"decort_cb_account_audits_list":               cb_account.DataSourceAccountAuditsList(),
		"decort_cb_account_available_templates_list":  cb_account.DataSourceAccountAvailableTemplatesList(),
		"decort_cb_audit":                             cb_audit.DataSourceAudit(),
		"decort_cb_audit_list":                        cb_audit.DataSourceAuditList(),
		"decort_cb_audit_linked_jobs":                 cb_audit.DataSourceAuditLinkedJobs(),
		"decort_cb_audits_export_to_file":             cb_audit.DataSourceAuditsToFile(),
		"decort_cb_dpdknet":                           cb_dpdknet.DataSourceDPDKNet(),
		"decort_cb_dpdknet_list":                      cb_dpdknet.DataSourceDPDKNetList(),
		"decort_cb_extnet":                            cb_extnet.DataSourceExtnetCB(),
		"decort_cb_extnet_list":                       cb_extnet.DataSourceExtnetListCB(),
		"decort_cb_extnet_default":                    cb_extnet.DataSourceExtnetDefaultCB(),
		"decort_cb_extnet_reserved_ip_list":           cb_extnet.DataSourceExtnetReservedIp(),
		"decort_cb_extnet_static_route_list":          cb_extnet.DataSourceStaticRouteList(),
		"decort_cb_extnet_static_route":               cb_extnet.DataSourceStaticRoute(),
		"decort_cb_image":                             cb_image.DataSourceImage(),
		"decort_cb_grid":                              cb_grid.DataSourceGrid(),
		"decort_cb_grid_get_status":                   cb_grid.DataSourceGridGetStatus(),
		"decort_cb_grid_post_status":                  cb_grid.DataSourceGridPostStatus(),
		"decort_cb_grid_get_diagnosis":                cb_grid.DataSourceGridGetDiagnosis(),
		"decort_cb_grid_get_settings":                 cb_grid.DataSourceGridGetSettings(),
		"decort_cb_grid_list":                         cb_grid.DataSourceGridList(),
		"decort_cb_grid_list_emails":                  cb_grid.DataSourceGridListEmails(),
		"decort_cb_grid_list_consumption":             cb_grid.DataSourceGridListConsumption(),
		"decort_cb_grid_get_consumption":              cb_grid.DataSourceGridGetConsumption(),
		"decort_cb_image_list":                        cb_image.DataSourceImageList(),
		"decort_cb_image_list_stacks":                 cb_image.DataSourceImageListStacks(),
		"decort_cb_kvmvm":                             cb_kvmvm.DataSourceCompute(),
		"decort_cb_kvmvm_affinity_relations":          cb_kvmvm.DataSourceComputeAffinityRelations(),
		"decort_cb_kvmvm_audits":                      cb_kvmvm.DataSourceComputeAudits(),
		"decort_cb_kvmvm_boot_order_get":              cb_kvmvm.DataSourceComputeBootOrderGet(),
		"decort_cb_kvmvm_get_audits":                  cb_kvmvm.DataSourceComputeGetAudits(),
		"decort_cb_kvmvm_get_console_url":             cb_kvmvm.DataSourceComputeGetConsoleUrl(),
		"decort_cb_kvmvm_get_log":                     cb_kvmvm.DataSourceComputeGetLog(),
		"decort_cb_kvmvm_list":                        cb_kvmvm.DataSourceComputeList(),
		"decort_cb_kvmvm_list_deleted":                cb_kvmvm.DataSourceComputeListDeleted(),
		"decort_cb_kvmvm_migrate_storage_info":        cb_kvmvm.DataSourceComputeMigrateStorageInfo(),
		"decort_cb_kvmvm_pci_device_list":             cb_kvmvm.DataSourceComputePCIDeviceList(),
		"decort_cb_kvmvm_pfw_list":                    cb_kvmvm.DataSourceComputePfwList(),
		"decort_cb_kvmvm_snapshot_list":               cb_kvmvm.DataSourceComputeSnapshotList(),
		"decort_cb_kvmvm_snapshot_usage":              cb_kvmvm.DataSourceComputeSnapshotUsage(),
		"decort_cb_kvmvm_user_list":                   cb_kvmvm.DataSourceComputeUserList(),
		"decort_cb_kvmvm_vgpu_list":                   cb_kvmvm.DataSourceComputeVGPUList(),
		"decort_cb_node":                              cb_node.DataSourceNode(),
		"decort_cb_node_list":                         cb_node.DataSourceNodeList(),
		"decort_cb_disk":                              cb_disks.DataSourceDisk(),
		"decort_cb_disk_list":                         cb_disks.DataSourceDiskList(),
		"decort_cb_disk_list_deleted":                 cb_disks.DataSourceDiskListDeleted(),
		"decort_cb_disk_list_types":                   cb_disks.DataSourceDiskListTypes(),
		"decort_cb_disk_list_types_detailed":          cb_disks.DataSourceDiskListTypesDetailed(),
		"decort_cb_disk_list_unattached":              cb_disks.DataSourceDiskListUnattached(),
		"decort_cb_disk_snapshot":                     cb_disks.DataSourceDiskSnapshot(),
		"decort_cb_disk_snapshot_list":                cb_disks.DataSourceDiskSnapshotList(),
		"decort_cb_disk_replication":                  cb_disks.DataSourceDiskReplication(),
		"decort_cb_pcidevice":                         cb_pcidevice.DataSourcePcidevice(),
		"decort_cb_pcidevice_list":                    cb_pcidevice.DataSourcePcideviceList(),
		"decort_cb_rg":                                cb_rg.DataSourceResgroup(),
		"decort_cb_rg_affinity_group_computes":        cb_rg.DataSourceRgAffinityGroupComputes(),
		"decort_cb_rg_affinity_groups_get":            cb_rg.DataSourceRgAffinityGroupsGet(),
		"decort_cb_rg_affinity_groups_list":           cb_rg.DataSourceRgAffinityGroupsList(),
		"decort_cb_rg_resource_consumption_get":       cb_rg.DataSourceRGResourceConsumptionGet(),
		"decort_cb_rg_resource_consumption_list":      cb_rg.DataSourceRGResourceConsumptionList(),
		"decort_cb_rg_audits":                         cb_rg.DataSourceRgAudits(),
		"decort_cb_rg_list":                           cb_rg.DataSourceRgList(),
		"decort_cb_rg_list_deleted":                   cb_rg.DataSourceRgListDeleted(),
		"decort_cb_rg_list_computes":                  cb_rg.DataSourceRgListComputes(),
		"decort_cb_rg_list_lb":                        cb_rg.DataSourceRgListLb(),
		"decort_cb_rg_list_pfw":                       cb_rg.DataSourceRgListPfw(),
		"decort_cb_rg_list_vins":                      cb_rg.DataSourceRgListVins(),
		"decort_cb_rg_usage":                          cb_rg.DataSourceRgUsage(),
		"decort_cb_sep_list":                          cb_sep.DataSourceSepList(),
		"decort_cb_sep":                               cb_sep.DataSourceSep(),
		"decort_cb_sep_and_pools_available_list":      cb_sep.DataSourceAvailableSEPAndPoolsList(),
		"decort_cb_sep_consumption":                   cb_sep.DataSourceSepConsumption(),
		"decort_cb_sep_disk_list":                     cb_sep.DataSourceSepDiskList(),
		"decort_cb_sep_config":                        cb_sep.DataSourceSepConfig(),
		"decort_cb_sep_pool":                          cb_sep.DataSourceSepPool(),
		"decort_cb_sep_template":                      cb_sep.DataSourceSepTemplate(),
		"decort_cb_lb":                                cb_lb.DataSourceLB(),
		"decort_cb_lb_list":                           cb_lb.DataSourceLBList(),
		"decort_cb_lb_list_deleted":                   cb_lb.DataSourceLBListDeleted(),
		"decort_cb_flipgroup_list":                    cb_flipgroup.DataSourceFlipgroupList(),
		"decort_cb_flipgroup":                         cb_flipgroup.DataSourceFlipgroup(),
		"decort_cb_stack_list":                        cb_stack.DataSourceStacksList(),
		"decort_cb_stack":                             cb_stack.DataSourceStack(),
		"decort_cb_user":                              cb_user.DataSourceUser(),
		"decort_cb_user_get_audit":                    cb_user.DataSourceUserGetAudit(),
		"decort_cb_user_list":                         cb_user.DataSourceUserList(),
		"decort_cb_vfpool":                            cb_vfpool.DataSourceVFPool(),
		"decort_cb_vfpool_list":                       cb_vfpool.DataSourceVFPoolList(),
		"decort_cb_vins":                              cb_vins.DataSourceVins(),
		"decort_cb_vins_list":                         cb_vins.DataSourceVinsList(),
		"decort_cb_vins_audits":                       cb_vins.DataSourceVinsAudits(),
		"decort_cb_vins_ip_list":                      cb_vins.DataSourceVinsIpList(),
		"decort_cb_vins_list_deleted":                 cb_vins.DataSourceVinsListDeleted(),
		"decort_cb_vins_ext_net_list":                 cb_vins.DataSourceVinsExtNetList(),
		"decort_cb_vins_nat_rule_list":                cb_vins.DataSourceVinsNatRuleList(),
		"decort_cb_vins_static_route":                 cb_vins.DataSourceStaticRoute(),
		"decort_cb_vins_static_route_list":            cb_vins.DataSourceStaticRouteList(),
		"decort_cb_k8ci":                              cb_k8ci.DataSourceK8CI(),
		"decort_cb_k8ci_list":                         cb_k8ci.DataSourceK8CIList(),
		"decort_cb_k8ci_list_deleted":                 cb_k8ci.DataSourceK8CIListDeleted(),
		"decort_cb_k8s":                               cb_k8s.DataSourceK8s(),
		"decort_cb_k8s_list":                          cb_k8s.DataSourceK8sList(),
		"decort_cb_k8s_list_deleted":                  cb_k8s.DataSourceK8sListDeleted(),
		"decort_cb_k8s_wg":                            cb_k8s.DataSourceK8sWg(),
		"decort_cb_k8s_wg_cloud_init":                 cb_k8s.DataSourceK8sWgCloudInit(),
		"decort_cb_k8s_wg_list":                       cb_k8s.DataSourceK8sWgList(),
		"decort_cb_k8s_computes":                      cb_k8s.DataSourceK8sComputes(),
	}
}
