/*
Copyright (c) 2019-2022 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Kasim Baybikov, <kmbaybikov@basistech.ru>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package vins

import (
	"context"
	"fmt"
	"strconv"
	"strings"

	log "github.com/sirupsen/logrus"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudapi/vins"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
)

func utilityDataStaticRouteCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (*vins.ItemRoutes, error) {
	c := m.(*controller.ControllerCfg)
	req := vins.StaticRouteListRequest{}
	var routeId uint64

	if d.Id() != "" {
		arr := strings.Split(d.Id(), "#")
		if len(arr) != 2 {
			return nil, fmt.Errorf("broken state id")
		}

		req.VINSID, _ = strconv.ParseUint(arr[0], 10, 64)
		routeId, _ = strconv.ParseUint(arr[1], 10, 64)
	} else {
		req.VINSID = uint64(d.Get("vins_id").(int))
		routeId = uint64(d.Get("route_id").(int))
	}

	log.Debugf("utilityStaticRouteCheckPresence, vins_id: %v", req.VINSID)
	staticRouteList, err := c.CloudAPI().VINS().StaticRouteList(ctx, req)
	if err != nil {
		return nil, err
	}

	log.Debugf("utilityStaticRouteCheckPresence: ROUTE ID %v", routeId)

	staticRoute := &vins.ItemRoutes{}
	for _, route := range staticRouteList.Data {
		if routeId == route.ID {
			staticRoute = &route
			return staticRoute, nil
		}
	}

	return nil, fmt.Errorf("static route not found")
}

func getStaticRouteData(ctx context.Context, d *schema.ResourceData, m interface{}) (*vins.ItemRoutes, error) {
	c := m.(*controller.ControllerCfg)
	req := vins.StaticRouteListRequest{}
	req.VINSID = uint64(d.Get("vins_id").(int))

	staticRouteList, err := c.CloudAPI().VINS().StaticRouteList(ctx, req)
	if err != nil {
		return nil, err
	}

	destination := d.Get("destination").(string)
	gateway := d.Get("gateway").(string)

	staticRoute := &vins.ItemRoutes{}
	for _, route := range staticRouteList.Data {
		if destination == route.Destination && gateway == route.Gateway {
			staticRoute = &route
			return staticRoute, nil
		}
	}

	return nil, fmt.Errorf("static route not found")
}
