Функция доступна в провайдере версии 4.5.1 и выше.

_Data source_ функция **decort_cb_audit_list** служит для получения списка событий системы, вызванных действиями пользователя.

## Аргументы
_Data source_ функция **decort_cb_audit_list** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| timestamp_at | int | :x: | Отдает все события, созданные после определенного времени (unix timstamp) |
| timestamp_to | int | :x: | Отдает все события, созданные до определенного времени (unix timstamp) |
| user | string | :x: | Пользователь для выборки (Mongo RegExp supported) |
| call | string | :x: | Фильтр по команде, которая была выполнена |
| min_status_code | int | :x: | Фильтр по минимальному статусу выполнения запроса |
| max_status_code | int | :x: | Фильтр по максимальному статусу выполнения запроса |
| sort_by | string | :x: | Фильтр по одному из поддерживаемых полей, формат: +или- название поля |
| page | int | :x: | Номер страниц |
| size | int | :x: | Размер страницы |

## Возвращаемые значения
В случае успешного выполнения _data source_ функция **decort_cb_audit_list** возвращает в указанную при вызове переменную, в поле _items_, массив, каждый элемент которого состоит из следующих параметров:

| Параметр | Тип | Описание |
| --- | --- | --- |
| call | string | Какая команда была выполнена |
| guid | string | ID ресурса |
| responsetime | float | Время выполнения |
| status_code | int | Статус выполнения |
| timestamp | float | Точное время исполнения |
| user | string | Кем была выполнена команда |

## Пример использования
Пример вызова _data source_ функции **decort_cb_audit_list**:

```terraform
data "decort_cb_audit_list" "audit_list" {
  #фильтр по аудитам с временной меткой после указанного значения
  #опциональный параметр
  #тип - целое число
  #timestamp_at = 123456

  #фильтр по аудитам с временной меткой до указанного значения
  #опциональный параметр
  #тип - целое число
  #timestamp_to = 123456

  #фильтр по пользователю (Mongo RegExp поддерживаются)
  #опциональный параметр
  #тип - строка
  #user = "username"

  #фильтр по api endpoint (Mongo RegExp поддерживаются)
  #опциональный параметр
  #тип - строка
  #call = "/restmachine/cloudbroker/audit/list"

  #фильтр по минимальному HTTP статус-коду
  #опциональный параметр
  #тип - целое число
  #min_status_code = 200

  #фильтр по максимальному HTTP статус-коду
  #опциональный параметр
  #тип - целое число
  #max_status_code = 500

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #size = 3
}
```

Данный пример подразумевает, что ранее по тексту tf-файла выполнена корректная инициализация провайдера (подробнее об инициализации Terraform провайдера DECORT см. соответствующий [раздел](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.6.0/04.02-Инициализация-Terraform-провайдера-DECORT.md) и [пример](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.6.0/02.-Пример-работы.md)). 

После успешного завершения такого вызова **decort_cb_audit_list** в переменной `data.decort_cb_audit_list.audit_list.items` будут сохранены возвращаемые значения.
