Функция доступна в провайдере версии 4.5.1 и выше.

_Resource_ функция **decort_cb_k8ci** служит для управления конфигурацией Кластера Kubernetes (K8ci).

## Аргументы

_Resource_ функция **decort_cb_k8ci** для создания кластера принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| name | string | :heavy_check_mark: | Наименование K8ci, <br/>при изменении - изменяет наименование K8ci |
| version | string | :heavy_check_mark: | Версия |
| master_driver | string | :heavy_check_mark: | Драйвер master-узла |
| master_image_id | int | :heavy_check_mark: | ID образа master-узла k8ci |
| max_master_count | int | :heavy_check_mark: | Ограничение политики на максимальное количество master-узлов |
| max_worker_count | int | :heavy_check_mark: | Ограничение политики на максимальное количество worker-узлов |
| worker_image_id | int | :heavy_check_mark: | ID образа worker-узла k8ci |
| worker_driver | string | :heavy_check_mark: | Драйвер worker-узла |
| network_plugins | []string | :heavy_check_mark: | Список доступных плагинов сети ["flannel", "calico", "weavenet"] |
| enabled | bool | :x: | Доступность k8ci |
| permanently | bool | :x: | Флаг для моментального удаления k8ci |
| desc | string | :x: | Описание k8ci |
| shared_with | []int | :x: | Список аккаунтов, имеющих доступ к k8ci |

## Возвращаемые значения

В случае успешного выполнения _resource_ функция **decort_cb_k8ci** возвращает в указанную при вызове переменную следующие значения:

| Параметр | Тип | Описание |
| --- | --- | --- |
| desc | string | Описание |
| gid | int | Grid ID |
| guid | int | ID ресурса |
| k8ci_id | int | ID k8ci |
| lb_image_id | int | ID образа балансировщика |
| master_driver | string | Драйвер master-узла |
| master_image_id | int | ID образа master-узла k8ci |
| max_master_count | int | Ограничение политики на максимальное количество master-узлов |
| max_worker_count | int | Ограничение политики на максимальное количество worker-узлов |
| milestones | int | Вехи |
| name | string | Наименование k8ci |
| network_plugins | []string | Список доступных плагинов сети |
| shared_with | []int | Список ресурсов, имеющих доступ к k8ci |
| status | string | Статус k8ci |
| version | string | Версия |
| worker_driver | string | Драйвер worker-узла |
| worker_image_id | int | ID образа worker-узла k8ci |

## Пример использования

Пример вызова _resource_ функции **decort_cb_k8ci**:

```terraform
resource "decort_cb_k8ci" "k8ci" {
  #имя k8ci
  #обязательный параметр
  #тип - строка
  name = "test"

  #тег версии
  #обязательный параметр
  #тип - строка
  version = "1.1.1"

  #тип master driver
  #обязательный параметр
  #тип - строка
  master_driver = "KVM_X86"

  #тип worker driver
  #обязательный параметр
  #тип - строка
  worker_driver = "KVM_X86"

  #максимальное число master компутов
  #обязательный параметр
  #тип - целое число
  max_master_count = 1

  #максимальное число worker компутов
  #обязательный параметр
  #тип - целое число
  max_worker_count = 1

  #id образа для master 
  #обязательный параметр
  #тип - целое число
  master_image_id = 4

  #id образа для worker 
  #обязательный параметр
  #тип - целое число
  worker_image_id = 4

  #network plugins
  #обязательный параметр
  #тип - массив строк
  network_plugins = ["flannel"]

  #доступность k8ci
  #опциональный параметр
  #тип - булев
  #enabled = false

  #флаг для моментального удаления k8ci
  #опциональный параметр
  #тип - булев
  #permanently = true

  #описание 
  #опциональный параметр
  #тип - строка
  #desc =  "some"

  #доступность k8ci другим аккаунтам
  #опциональный параметр
  #тип - массив целых чисел
  #shared_with = [1111]
}

# once the above directive completes, k8ci configuration will be accessible
# as decort_cb_k8ci.k8ci
```

Данный пример подразумевает, что ранее по тексту tf-файла выполнена корректная инициализация провайдера (подробнее об инициализации Terraform провайдера DECORT см. соответствующий [раздел](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.6.4/04.02-Инициализация-Terraform-провайдера-DECORT.md)).

После успешного завершения такого вызова **decort_cb_k8ci** в переменной `decort_cb_k8ci.k8ci` будут сохранены возвращаемые значения.
