Функция доступна в провайдере версии 4.5.1 и выше.

_Resource_ функция **decort_cb_sep** служит для управления storage endpoint. Storage endpoint (sep) - точка доступа к хранилищу данных. Sep бывает четырех типов:

- des
- hitachi
- dorado
- tatlin

Каждый тип отличается возможной конфигурацией.  
_Resource_ функция **decort_cb_sep** позволяет создавать, удалять sep. Изменение существующего ресурса через terraform не возможно. Обо всех доступных полях конфигурации для каждого типа storage endpoint см. ниже.

## Аргументы

_Resource_ функция **decort_cb_sep** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| gid | int | :heavy_check_mark: | Grid id |
| name | string | :heavy_check_mark: | Наименование sep |
| type | string | :heavy_check_mark: | Тип sep.<br/>Возможные значения:<br/>des<br/>hitachi<br/>tatlin<br/>dorado |
| config | json string | :heavy_check_mark: | Конфигурация sep. Используется при создании sep |
| desc | string | :x: | Описание sep, используется при создании sep |
| enable | bool | :x: | Доступность sep, используется при создании sep |
| consumed_by | []int | :x: | Используемые nodes, используется при создании sep |
| provided_by | []int | :x: | Используемые provider nodes, используется при создании sep |
| sep_id | int | :x: | Используется для формирования .tfstate, в случае его удаления и присутствия sep с указанным id в системе |
| account_ids | []int | :x: | Предоставление/отключение доступа указанных аккаунтов к sep, используется при создании sep |
| access_to_pool | Struct{<br/>pool_name string<br/>account_id_pool int<br/>rg_id int<br/>} | :x: | Предоставление/отключение доступа к пулу на sep<br/>&nbsp;<br/>Название pool (обязательный параметр)<br/>&nbsp;<br/>id аккаунта<br/>&nbsp;<br/>id ресурсной группы |
| pools     | Struct [см. ниже](#описание-структуры-pools)          | :x:                | Добавление/удаление pools к/из sep |

### Описание структуры pools
| Параметр | Тип | Описание |
| --- | --- | --- |
| access_account_ids | []int |  Идентификаторы учетных записей доступа |
| access_res_group_ids | []int |  Идентификаторы групп ресурсов доступа |
| name | string | Имя пула |
| types | []string | Тип пула |
| topology | string | Топология |
| uris | Struct{<br/>ip<br/>port<br/>} | Адреса узлов хранения<br/>ip адрес узла<br/>Порт узла  |
| usage_limit | int | Доступный объем пула |

## Возвращаемые значения

В случае успешного выполнения _data source_ функция **decort_cb_sep** возвращает в указанную при вызове переменную элемент, который состоит из следующих параметров:

| Параметр | Тип | Описание |
| --- | --- | --- | 
| sep_id | int | id storage endpoint |
| ckey | string | CKey |
| meta | []string | Мета информация о sep |
| consumed_by | []int | Список node id, использующих sep |
| desc | string | Описание sep |
| gid | int | Grid id, к которому привязан sep |
| guid | int | Внутренний id sep |
| milestones | int | Вехи |
| name | string | Наименование sep |
| obj_status | string | Статус sep |
| provided_by | []int | Список provider id, использующих sep |
| shared_with | []int | Список id учетных записей, у которых есть доступ к sep |
| tech_status | string | Технический статус sep |
| type | string | Тип sep |
| config | json string | Конфигурация sep |
| upd_capacity_limit | bool | Обновление предела емкости, используется при редактировании sep |
| enable | bool | Доступность sep, используется при создании и редактировании sep |
| account_ids | []int | Предоставление/отключение доступа указанных аккаунтов к sep, используется при создании и редактировании sep |
| access_to_pool | Struct{<br/>pool_name string<br/>account_id_pool int<br/>rg_id int<br/>} | Предоставление/отключение доступа к пулу на sep<br/>&nbsp;<br/>Название pool (обязательный параметр)<br/>&nbsp;<br/>id аккаунта<br/>&nbsp;<br/>id ресурсной группы |

## Пример использования

Пример вызова _resource_ функции **decort_cb_sep**:

```terraform
resource "decort_cb_sep" "s" {
  #grid id
  #обязательный параметр
  #тип - целое число
  gid = 111

  #sep name
  #обязательный параметр
  #тип - строка
  name = "test sep"

  #тип sep
  #обязательный параметр
  #возможные значения - des, dorado, tatlin, hitachi
  #тип - строка
  type = "des"

  #конфигурация sep
  #обязательный параметр
  #мб применен при создании sep
  #представляет собой json-строку
  #тип - строка
  config = file("./config.json")

  #описание sep
  #опциональный параметр
  #используется при создании ресурса
  #тип - строка
  #desc = "rrrrr"

  #предоставление/отключение доступа указанных аккаунтов к sep
  #опциональный параметр, используется при создании ресурса
  #тип - массив целых чисел
  #account_ids = [12, 245]

  #предоставление/отключение доступа к пулу на sep
  #опциональный параметр, может быть применен на уже созданном sep
  #тип - блок доступа к пулу
  #access_to_pool {
  #имя pool
  #обязательный параметр
  #тип - строка
  #pool_name  = "pool name"

  #id аккаунта
  #опциональный параметр
  #тип - целое число
  #account_id_pool = 123

  #id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 1234
  #}

  #доступность sep
  #опциональный параметр
  #может быть применен на уже созданном ресурсе
  #по умолчанию - false
  #тип - булев
  #enable = false

  #использование нодами
  #опциональный параметр
  #используется при создании ресурса
  #тип - массив целых чисел
  #consumed_by = []

  #обновление лимита объема
  #опциональный параметр
  #применяется на уж созданном ресурсе
  #тип - булев
  #upd_capacity_limit = true

  #id provided nodes
  #опциональный параметр
  #используется при создании ресурса
  #тип - массив целых чисел
  #provided_by = [16, 14, 15]

  #отключение nodes
  #опциональный параметр
  #применяется на уже созданном ресурсе
  #используется в связке с clear_physically
  #по умолчанию - true
  #тип - булев
  #decommission = true

  #физическое очищение nodes
  #опциональный параметр
  #используется при удалении ресурса
  #внимание, во избежание конфликтов использовать только в связке с полем decommission = true
  #тип - булев
  #clear_physically = false

  #добавление/удаление pools к/из sep 
  #опциональный параметр
  #используется при создании ресурса, состоит из имен pool
  #тип - массив строк
  #тип - блок pools
  pools {
    #идентификаторы учетных записей доступа
    #обязательный параметр
    #тип - массив целых чисел
    access_account_ids = [1, 2, 3]

    #идентификаторы групп ресурсов доступа
    #обязательный параметр
    #тип - массив целых чисел
    access_res_group_ids = [10, 20, 30]  

    #имя пула
    #опциональный параметр
    #тип - строка   
    name = "example_pool_name"

    #тип пула
    #опциональный параметр
    #тип - массив строк                 
    types = ["type1", "type2"]

    #адреса узлов хранения
    #опциональный параметр
    #тип - блок ip адресов   
    uris {
      #ip адрес узла
      #обязательный параметр
      #тип - строка
      ip = "192.168.1.1"   
      
      #порт узла
      #обязательный параметр
      #тип - целое число
      port = 8080                         
      }

    #доступный объем пула
    #обязательный параметр
    #тип - целое число
    usage_limit = 1000
  }

}
# and config will be accessible
# as decort_cb_sep.s.config
```

Данный пример подразумевает, что ранее по тексту tf-файла выполнена корректная инициализация провайдера (подробнее об инициализации Terraform провайдера DECORT см. соответствующий [раздел](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.7.4/04.02-Инициализация-Terraform-провайдера-DECORT.md)).

После успешного завершения такого вызова **decort_cb_sep** в переменной `decort_cb_sep.s` будут сохранены возвращаемые значения.

Чтобы получить доступ к конфигурации и сохранить ее в файл .json, необходимо:

1. определить в .tf - файле дополнительный output с любым именем, в который запишется информация о конфигурации sep и обернуть ее в вызов функции jsondecode для декодирования информации.

```terraform
output "sep_config" {
    value = jsondecode(decort_cb_sep.s.config)
}
```

2. Применить изменения в терраформе.

```bash
terraform apply
```

3. Сохранить данные из output в .json - файл.

```bash
terraform output -json sep_config >> config.json
```

В общем случае это будет выглядеть как указано ниже.

```bash
terraform output -json <output-name> >> <file-name>.json
```

## Примеры возможных конфигураций для разных типов sep

Поля в разных версиях decort могут отличаться.
Конфигурация перед отправкой проходит валидацию.

### des

| Поле | Тип | Описание |
| --- | --- | --- |
| API_IPs | []string | Список ip адресов для api |
| protocol | string | Протокол сообщения с sep |
| decs3o_app_secret | string | Секретный ключ decs3o |
| format | string | Формат передачи данных |
| edgeuser_password | string | Пароль пользователя |
| edgeuser_name | string | Имя пользователя |
| decs3o_app_id | string | APP ID, полученный в decs3o |
| transport | string | Транспортный протокол |

```json
{
  "API_IPs": ["11.111.1.11", "11.111.1.12", "11.111.1.13", "11.111.1.14"],
  "protocol": "des",
  "decs3o_app_secret": "",
  "format": "raw",
  "edgeuser_password": "somepassword",
  "housekeeping_settings": {
    "disk_del_queue": {
      "purgatory_id": 1
    }
  },
  "edgeuser_name": "someusername",
  "decs3o_app_id": "",
  "ovs_settings": {},
  "pools": [
    {
      "types": ["D"],
      "referenceId": "somerefid",
      "name": "poolname2",
      "pagecache_ratio": 100,
      "uris": [
        {
          "ip": "11.111.1.11",
          "port": 11
        },
        {
          "ip": "11.111.1.12",
          "port": 11
        },
        {
          "ip": "11.111.1.13",
          "port": 11
        },
        {
          "ip": "11.111.1.14",
          "port": 11
        }
      ]
    },
    {
      "types": ["D"],
      "referenceId": "somerefid2",
      "name": "poolname1",
      "pagecache_ratio": 100,
      "uris": [
        {
          "ip": "11.111.1.11",
          "port": 12
        },
        {
          "ip": "11.111.1.12",
          "port": 12
        },
        {
          "ip": "11.111.1.13",
          "port": 12
        },
        {
          "ip": "11.111.1.14",
          "port": 12
        }
      ]
    },
    {
      "types": ["B"],
      "referenceId": "somerefid3",
      "name": "myname",
      "pagecache_ratio": 100,
      "uris": [
        {
          "ip": "11.111.1.11",
          "port": 13
        },
        {
          "ip": "11.111.1.12",
          "port": 13
        },
        {
          "ip": "11.111.1.13",
          "port": 13
        },
        {
          "ip": "11.111.1.14",
          "port": 13
        }
      ]
    }
  ],
  "transport": "tcp"
}
```

### hitachi

| Поле | Тип | Описание |
| --- | --- | --- |
| API_URLs | []string | Список адресов для api |
| SN | string | Серийный номер |
| format | string | Формат передачи данных |
| disk_max_size | int | Максимальный размер диска |
| mgmt_password | string | Пароль пользователя |
| mgmt_user | string | Имя пользователя |
| model | string | Модель |
| name_prefix | string | Префикс в имени |
| protocol | string | Протокол сообщения |
| ssl_verify | bool | Проверка ssl |

```json
{
  "API_URLs": ["https://11.11.111.11:11", "https://11.11.111.12:11"],
  "SN": 1111,
  "disk_max_size": 111,
  "format": "raw",
  "hostGroupNumMax": 1,
  "hostGroupNumMin": 1,
  "hostGroupNumber": 1,
  "housekeeping_settings": {
    "disk_del_queue": {
      "purge_attempts_threshold": 20
    }
  },
  "mgmt_password": "pwd",
  "mgmt_user": "username",
  "model": "model",
  "name_prefix": "my-prefix-",
  "pools": [
    {
      "clone_technology": "snapshot",
      "id": 1,
      "maxLdevId": 1111,
      "minLdevId": 111,
      "name": "my-prefix-01",
      "snapshot_pool_id": 1,
      "snapshotable": true,
      "types": ["D", "B", "ANY"],
      "usage_limit": 999999999
    },
    {
      "clone_technology": "snapshot",
      "id": 2,
      "maxLdevId": 1111,
      "minLdevId": 111,
      "name": "my-prefix-92-snap",
      "snapshot_pool_id": 1,
      "snapshotable": true,
      "types": [],
      "usage_limit": 111
    }
  ],
  "ports": ["port-name-1", "port-name-2"],
  "protocol": "scsi",
  "ssl_verify": false
}
```

### dorado

| Поле | Тип | Описание |
| --- | --- | --- |
| API_URLs | []string | Список адресов для api |
| edgeuser_password | string | Пароль пользователя |
| edgeuser_name | string | Имя пользователя |
| format | string | Формат передачи данных |
| disk_max_size | int | Максимальный размер диска |
| mgmt_password | string | Пароль пользователя |
| mgmt_user | string | Имя пользователя |
| model | string | Модель |
| name_prefix | string | Префикс в имени |
| protocol | string | Протокол сообщения |

```json
{
  "API_URLs": ["https://111.11.111.111:11/"],
  "disk_max_size": 111,
  "edgeuser_name": "username",
  "edgeuser_password": "pwd",
  "format": "raw",
  "groups": {
    "hostgroup": ["hostname", "1"],
    "lungroup": ["hostname_lungroup", "2"],
    "portgroup": ["hostname_portgroup", "3"]
  },
  "hostGroupName": "hostname",
  "housekeeping_settings": {
    "disk_del_queue": {
      "purge_attempts_threshold": 20
    }
  },
  "mgmt_password": "pwd2",
  "mgmt_user": "username2",
  "model": "Dorado",
  "name_prefix": "my-prefix-",
  "pools": [
    {
      "name": "pool1",
      "types": ["D", "B", "ANY"],
      "usage_limit": 111111
    }
  ],
  "ports": [
    {
      "ip": "11.111.1.111",
      "name": "port1"
    },
    {
      "ip": "11.111.1.112",
      "name": "port2"
    },
    {
      "ip": "11.111.1.113",
      "name": "myport3"
    }
  ],
  "protocol": "iscsi"
}
```

### tatlin

| Поле | Тип | Описание |
| --- | --- | --- |
| API_URLs | []string | Список адресов для api |
| edgeuser_password | string | Пароль пользователя |
| edgeuser_name | string | Имя пользователя |
| format | string | Формат передачи данных |
| disk_max_size | int | Максимальный размер диска |
| mgmt_password | string | Пароль пользователя |
| mgmt_user | string | Имя пользователя |
| model | string | Модель |
| name_prefix | string | Префикс в имени |
| protocol | string | Протокол сообщения |

```json
{
  "API_URLs": ["ssh://111.11.11.11:43"],
  "disk_max_size": 1111,
  "edgeuser_name": "usrname",
  "edgeuser_password": "pwd",
  "format": "raw",
  "hostGroupName": "mygroupname",
  "housekeeping_settings": {
    "disk_del_queue": {
      "purge_attempts_threshold": 20
    }
  },
  "mgmt_password": "pwd2",
  "mgmt_user": "usrname",
  "model": "Tatlin",
  "name_prefix": "my-prefix-",
  "pools": [
    {
      "name": "pool-name",
      "types": ["D", "B"],
      "usage_limit": 11111
    }
  ],
  "ports": [
    {
      "ips": ["111.11.111.113", "111.11.111.114"],
      "iqn": "some_iqn_string",
      "name": "myportname"
    },
    {
      "ips": ["111.11.111.113", "111.11.111.114"],
      "iqn": "myiqnstring",
      "name": "myportname"
    }
  ],
  "protocol": "iscsi",
  "techDisk": {
    "name": "mydiskname",
    "pool": "pool-name",
    "size": 1,
    "wwid": "wwidstring"
  }
}
```
