Функция доступна в провайдере версии 4.5.1 и выше.

_Data source_ функция **decort_cb_image** служит для получения информации об имеющихся в облачной платформе образах. Образы это дисковые ресурсы, уже содержащие некоторые данные ("golden image"), для которых реализован механизм быстрого клонирования/копирования в новый диск. 

Основной сценарий использования таких ресурсов это создание каталогов образов операционных систем (ОС), на базе которых создаются загрузочные диски для _compute_. Также с их помощью можно хранить эталонную информацию, требующуюся для работы приложений, например, файлы баз данных.

Образ ОС является основной для создания новых виртуальных серверов, так как из него формируется загрузочный диск сервера. Как следствие, для создания виртуального сервера помимо других параметров требуется указать идентификатор нужного образа ОС. Для получения такого идентификатора можно воспользоваться _data source_ функцией **decort_cb_image**.

## Аргументы
_Data source_ функция **decort_cb_image** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| image_id | int | :heavy_check_mark: | ID образа, информацию по которому требуется получить. |

ID необходимого образа можно взять вызвав [decort_cb_image_list](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.8.1/06.02.06-Data_decort_cb_image_list.md)

## Возвращаемые значения
В случае успешного выполнения _data source_ функция **decort_cb_image** возвращает в указанную при вызове переменную следующие значения:

| Параметр | Тип | Описание |
| --- | --- | --- |
| account_id | int | accountId привязки образа |
| acl | []Struct [см. ниже](#описание-структуры-acl) | Cписок Acces Control |
| architecture | string | Архитектура образа, возможен вариант X86_64 |
| boot_type | string | Тип запуска ОС - bios или uefi |
| bootable | bool | Является ли образ загрузочным |
| cd_presented_to | string | Каким виртуальным машинам предоставлен CD образ |
| computeci_id | int | ID вычислительного ресурса |
| deleted_time | int | Время удаления |
| desc | string | Описание образа |
| drivers | []string | Список используемых драйверов |
| enabled | bool | Доступность образа |
| gid | int | ID платформы, где образ будет создан |
| guid | int | Внутренний id образа, совпадает с image_id |
| history | []Struct [см. ниже](#описание-структуры-history) | История обновлений образа |
| hot_resize | bool | Использует ли машина горячее изменение размера образа |
| image_id | int | ID образа |
| last_modified | int | Дата последнего изменения |
| link_to | int | Привязка к образу, используется в виртуальных образах |
| milestones | int | Вехи |
| name | string | Название образа |
| network_interface_naming | string | Название сетевого интерфейса |
| password | string | Пароль для образа |
| pool_name | string | Пул, в котором был создан образ |
| present_to | []int | Список ID ресурсов для который предоставлен образ |
| provider_name | string | Наименование провайдера |
| purge_attempts | int | Попытки |
| reference_id | string | ID ссылки |
| res_id | string | ID ресурса |
| res_name | string | Наименование ресурса |
| rescuecd | bool | CD или нет |
| sep_id | int | storage endpoint provider ID |
| shared_with | []int | Список ресурсов, имеющих доступ к образу |
| size | int | Размер образа |
| snapshot_id | string | ID снапшота |
| status | string | Статус образа |
| tech_status | string | Технический статус |
| image_type | string | Тип образа: linux, windows или другой |
| unc_path | string | unc path |
| url | string | Адрес, которого осуществлялась загрузка образа |
| username | string | Имя пользователя образа |
| version | string | Версия |

### Описание структуры acl
| Параметр | Тип | Описание |
| --- | --- | --- |
| explicit | bool | Явно ли указан доступ |
| guid | string | guid Ресурса |
| right | string | Права на ресурс |
| status | string | Статус ресурса |
| type | string | Тип ресурса |
| user_group_id | string | ID user group |

### Описание структуры history
| Параметр | Тип | Описание |
| --- | --- | --- |
| id | int | id записи об обновлении образа |
| guid | string | guid ресурса |
| timestamp | int | временная метка |

## Пример использования
Пример вызова _data source_ функции **decort_cb_image**:
```terraform
data "decort_cb_image" "my_img" {
  #id образа
  #обязательный параметр
  #тип - целое число
  image_id = 5912
}
```

Данный пример подразумевает, что ранее по тексту tf-файла выполнена корректная инициализация провайдера (подробнее об инициализации Terraform провайдера DECORT см. соответствующий [раздел](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.8.1/04.02-Инициализация-Terraform-провайдера-DECORT.md)). 

После успешного завершения такого вызова **decort_cb_image** в переменной `data.decort_cb_image.my_img` будут сохранены возвращаемые значения. В частности, для получения идентификатора образа следует использовать конструкцию `data.decort_cb_image.my_img.name`
