_Data source_ функция **decort_rg_usage** служит для получения информации о использовании ресурсов rg.

Ресурсная группа в облачной платформе DECORT это способ группирования _compute_-ов (например, по функциональному признаку или принадлежности к одному и тому же проекту). Ресурсную группу можно рассматривать как небольшой персональный дата-центр, в котором размещаются один или несколько серверов и виртуальных сетевых сегментов (ViNS).

Экземпляры _compute_ (виртуальные серверы) всегда создаются в принадлежности к какой-либо ресурсной группе. Как следствие, для создания экземпляра _compute_ помимо других параметров требуется указать идентификатор целевой ресурсной группы. Для получения такого идентификатора можно воспользоваться рассматриваемой здесь _data source_ функцией **decort_rg_usage**.

## Аргументы
_Data source_ функция **decort_rg_usage** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| rg_id | int | :heavy_check_mark: | Идентификатор ресурсной группы |

Пользователь облачной платформы, от лица которого происходит обращение к данной функции, должен иметь доступ к указанному `account` и ресурсной группе. В противном случае возникнет ошибка доступа.

Пользователь облачной платформы задается на стадии инициализации Terraform провайдера DECORT (см. [подробности](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.8.3/04.02-Инициализация-Terraform-провайдера-DECORT.md)).

## Возвращаемые значения
В случае успешного выполнения _data source_ функция **decort_rg_usage** возвращает в указанную при вызове переменную, в поле _items_, массив, каждый элемент которого состоит из следующих параметров:
| Параметр | Тип | Описание |
| --- | --- | --- |
| cpu | int | Количество виртуальных CPU, выделенных данному серверу. |
| disk_size | int | Размер диска |
| disk_size_max | int | Максимальный размер диска |
| extips | int | Extips |
| exttraffic | int | Exttraffic |
| gpu | int | Количество GPU |
| ram | int | Количество RAM |
| seps | []Struct [см. ниже](#описание-структуры-seps) | Информация о сепах |

### Описание структуры seps
| Параметр | Тип | Описание |
| --- | --- | --- |
| sep_id | string | Идентификатор сепа |
| map | map[string]string | Информация хранящаяяся внутри сепа |

## Пример использования
Пример вызова _data source_ функции **decort_rg_usage**:

```terraform
data "decort_rg_usage" "rg_usage" {
  #id ресурсной группы
  #обязательный параметр
  #тип - целое число

  rg_id = 123
}
```

Данный пример подразумевает, что ранее по тексту tf-файла выполнена корректная инициализация провайдера (подробнее об инициализации Terraform провайдера DECORT см. соответствующий [раздел](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.8.3/04.02-Инициализация-Terraform-провайдера-DECORT.md) и [пример](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.8.3/02.-Пример-работы.md)). 

После успешного завершения такого вызова **decort_rg_usage** в переменной `data.decort_rg_usage.rg_usage` будут сохранены возвращаемые значения. В частности, для получения идентификатора ресурсной группы следует использовать конструкцию `data.decort_rg_usage.rg_usage.id`
