Функция доступна в версии провайдера 4.5.1 и выше.

_Resource_ функция **decort_cb_rg** служит для управления ресурсными группами в облачной платформе DECORT.

## Аргументы
_Resource_ функция **decort_cb_rg** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| account_id | int | :heavy_check_mark: | Идентификатор аккаунта (aka "account"), которому будет принадлежать создаваемая ресурсная группа. |
| rg_name | string | :heavy_check_mark: | Имя ресурсной группы. Должно быть уникальным в рамках одного и того же  аккаунта ("account"), не может быть пустым. |
| gid | int | :heavy_check_mark: | Идентификатор площадки (grid id) |
| compute_features | []string | :x: | Доступ к дополнительным функциям управления ВМ |
| owner | string | :x: | Имя пользователя – владелец этой РГ. Оставьте поле пустым, чтобы назначить текущего пользователя владельцем. |
| def_net_type | string | :x: | Тип сети, которая будет установлена по умолчанию для данной ресурсной группы. <br> Данный параметр используется только при создании resourse. Во всех остальных случаях необходимо пользоваться параметром def_net. <br>Может принимать одно из следующих значений:<br> * "PUBLIC" - создаваемые в данной ресурсной группе экземпляры _compute_ по умолчанию будут подключаться во внешнюю сеть с идентификатором, который задаётся параметром `ext_net_id`<br> * "PRIVATE" - экземпляры _compute_ по умолчанию будут подключаться в новый виртуальный сетевой сегмент (ViNS ), который платформа автоматически создаст для данной ресурсной группы.<br> * "NONE" - сеть по умолчанию не задана, экземпляры _compute_ в данной ресурсной группе будут создаваться без сетевых подключений, если при их создании явно не указано иное. <br>По умолчанию: PRIVATE |
| description | string | :x: | Текстовое описание данной ресурсной группы.<br/>Данный параметр не является обязательным, значение по умолчанию - пустая строка. |
| ext_ip | string | :x: | IP адрес из диапазона, принадлежащего внешней сети, который будет присвоен подключению ViNS во внешнюю сеть в случае, когда `def_net_type = "PRIVATE"` и ненулевом `ext_net_id`. При других значениях `def_net_type` данный параметр игнорируется.<br/>Если данный параметр не указан явно, то платформа автоматически выберет свободный IP адрес.<br/>Если заданный `ext_ip` уже используется, платформа вернёт ошибку. |
| ext_net_id | int | :x: | Идентификатор внешней сети, в которую будет подключён ViNS, автоматически создаваемый платформой для данной ресурсной группы в случае, когда `def_net_type = "PRIVATE"`. При других значениях `def_net_type` данный параметр игнорируется.<br/>Если данный параметр не задан явно при `def_net_type = "PRIVATE"`, то платформа выберет первую из доступных данному пользователю внешних сетей. |
| ipcidr | string | :x: | Адрес сети внутри ViNS для случая `def_net_type = "PRIVATE"`<br/>Если данный параметр явно не задан, то платформа назначит адрес сети автоматически. |
| resource_limits | struct [см. ниже](#описание-структуры-resource_limits) | :x: | Квоты на объем ресурсов, устанавливаемые для данной ресурсной группы, с разбивкой по количеству CPU, объему RAM, объему дисковых ресурсов, количеству внешних IP адресов и т.п. Максмальное количество: 1 |
| uniq_pools | []string | :x: | Список пулов. Например, ["sep1_poolName1", "sep2_poolName2"] |
| access | []Struct [см. ниже](#описание-структуры-access) | :x: | Пользователи которым выдется доступ к данной ресурсной группе  |
| def_net | Struct [см. ниже](#описание-структуры-def_net) | :x: | Параметры сети ресурсной группы. Если используется, поле def_net_type игнорируется. Максмальное количество: 1 |
| cpu_allocation_parameter | string | :x: | Установить тип выделения ЦП:<br/>`strict` – ВМ не может быть запущена, если не хватает ресурсов ЦП;<br/>`loose` - можно запускать виртуальную машину, если не хватает ресурсов. |
| cpu_allocation_ratio | float | :x: | Установить коэффициент распределения ЦП для УЗ. Один pCPU = ratio*vCPU |
| enable | bool | :x: | Флаг доступности ресурсной группы |
| restore | bool | :x: | Флаг восстановления ресурсной группы<br/>Используется при редактировании |
| permanently | bool | :x: | Безвозвратное удаление ресурсной группы. Используется при удалении |
| force | bool | :x: | Удаление ресурсной группы, в случае если она к чему-то присоединена произойдет отсоединение от других ресурсов и удаление |

Для создания ресурсной группы пользователь облачной платформы, от лица которого происходит обращение к данной функции, должен иметь как минимум доступ на запись к указанному аккаунту. В противном случае возникнет ошибка доступа.

Пользователь облачной платформы задается на стадии инициализации Terraform провайдера DECORT (см. [подробности](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.9.0/04.02-Инициализация-Terraform-провайдера-DECORT.md)).

## Возвращаемые значения
В случае успешного выполнения _resource_ функция **decort_cb_rg** возвращает в указанную при вызове переменную следующие значения:

| Параметр | Тип | Описание 
| --- | --- | --- |
| account_id | int | Уникальный идентификатор аккаунта-владельца данной ресурсной группы. |
| account_name | string | Имя аккаунта ("account"), которому принадлежит данная ресурсная группа. |
| compute_features | []string | Доступ к дополнительным функциям управления ВМ |
| acl | []Struct [см. ниже](#описание-структуры-acl) | Cписок Acces Control |
| cpu_allocation_parameter | string | Параметр выделения CPU |
| cpu_allocation_ratio | float | Отношение выделения CPU |
| created_by | string | Пользователь - создатель ресурсной группы |
| created_time | int | Время создания ресурсной группы |
| def_net_id | int | Уникальный идентификатор сети, установленной по умолчанию для данной ресурсной группы. Экземпляры _compute_, создаваемые в данной ресурсной группе, по умолчанию будут иметь подключение к данной сети, если при их создании явно не указано иное.<br/>Для `def_net_type = "EXTNET" в этом параметре указан идентификатор внешней сети. Для `def_net_type = "PRIVATE" - идентификатор ViNS. |
| def_net_type | string | Тип сети, которая будет установлена по умолчанию для данной ресурсной группы. <br> Данный параметр используется только при создании resourse. Во всех остальных случаях необходимо пользоваться параметром def_net. <br>Может принимать одно из следующих значений:<br> * "PUBLIC" - создаваемые в данной ресурсной группе экземпляры _compute_ по умолчанию будут подключаться во внешнюю сеть с идентификатором, который задаётся параметром `ext_net_id`<br> * "PRIVATE" - экземпляры _compute_ по умолчанию будут подключаться в новый виртуальный сетевой сегмент (ViNS ), который платформа автоматически создаст для данной ресурсной группы.<br> * "NONE" - сеть по умолчанию не задана, экземпляры _compute_ в данной ресурсной группе будут создаваться без сетевых подключений, если при их создании явно не указано иное. <br>По умолчанию: PRIVATE |
| deleted_by | string | Информация о том, кто удалил группу |
| deleted_time | int | Время удаления группы |
| description | string | Текстовое описание данной ресурсной группы. |
| gid | int | GRID ID |
| guid | int | ID ресурса |
| lock_status | string | Статус доступности |
| milestones | int | Вехи |
| rg_name | string | Имя данной ресурсной группы. Обратите внимание, что имя ресурсной группы является уникальным только в рамках одного и того же аккаунта ("account"). |
| rg_id | int | Идентификатор данной ресурсной группы. |
| resource_limits | []Struct [см. ниже](#описание-структуры-resource_limits) | Лимиты ресурсов |
| resource_types | []string | Типы ресурсов |
| secret | string | Секрет |
| status | string | Статус ресурсной группы |
| uniq_pools | []string | Список пулов. Например, ["sep1_poolName1", "sep2_poolName2"] |
| updated_by | string | Кем был обновлен ресурс |
| updated_time | int | Время последнего обновления ресурса |
| vins | []int | Список виртуальных сетей |
| vms | []int | Список id компьютов |

### Описание структуры acl
| Параметр | Тип | Описание |
| --- | --- | --- |
| explicit | bool | Видимость аккаунта |
| guid | string | GUID |
| right | string | Права |
| status | string | Статус |
| type | string | Тип |
| user_group_id | string | ID группы юзеров |

### Описание структуры resource_limits
| Параметр | Тип | Описание |
| --- | --- | --- |
| cu_c | float | Количество ядер CPU |
| cu_d | float | Размер диска, вычисляемый параметр |
| cu_dm | float | Использованный размер хранилища виртуального диска |
| cu_i | float | Количество публичных IP адресов |
| cu_m | float | размер RAM |
| cu_np | float | Хранилище траффика |
| gpu_units | float | количество GPU ядер, вычисляемый параметр |

### Описание структуры access
| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| user | string | :heavy_check_mark: | Юзер которому предоставляется доступ |
| right | string | :heavy_check_mark: | Права, которые будут выдаваться данному юзеру. Возможные значения: "R", "RCX" или "ARCXDU" |

### Описание структуры def_net
| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| net_type | string | :heavy_check_mark: | Тип сети, которая будет присоединена к ресурсной группе. Возможные значения: "PRIVATE" - vins, "PUBLIC"- external network | 
| net_id | int | :x: | Идентификатор сети. Если не указан, будет задан тот, к которому есть доступ по умолчанию |

## Пример использования
В нижеприведённом примере с помощью _resource_ функции **decort_cb_rg** создаётся ресурсная группа со следующими характеристиками:
* Имя создаваемой ресурсной группы - "testing_rg_1"
* Идентификатор аккаунта-владельца ("account") - 123
* Gid площадки - 1234
* Квоты на объёмы ресурсов отсутствуют (нет ограничений).

```terraform
resource "decort_cb_rg" "rg" {
  #имя ресурсной группы
  #обязательный параметр
  #тип - строка
  #используется при создании и обновлении
  rg_name = "testing_rg_1"

  #id аккаунта которому будет принадлежать ресурсная группа
  #обязательный параметр
  #тип - целое число
  #используется при создании
  account_id = 123

  #id сети
  #обязательный параметр
  #тип - целое число
  #используется при создании
  gid = 1234

  #лимиты ресурсов
  #опциональные параметры
  #тип - блок лимитов на ресурсы
  #используется при создании и обновлении
  #resource_limits  {
    #максимальное количество ядер cpu
    #опциональный параметр
    #тип - целое число
    #cu_c = 12

    #максимальный размер агрегированных виртуальных дисков в ГБ
    #опциональный параметр
    #тип - целое число
    #cu_dm = 12

    #максимальное количество назначенных общедоступных IP-адресов
    #опциональный параметр
    #тип - целое число
    #cu_i = 12

    #максимальный объем памяти в МБ
    #опциональный параметр
    #тип - целое число
    #cu_m = 12

    #максимальный пиринг отправленных/принятых сетевых передач
    #опциональный параметр
    #тип - целое число
    #cu_np = 12
  #}

  #имя владельца ресурсной группы
  #опциональный параметр
  #тип - строка
  #используется при создании
  #owner = "owner name"

  #тип сети по умолчанию для этой ресурсной группы. 
  #виртуальные машины, созданные в этой RG, по умолчанию будут подключены к этой сети. 
  #допустимые значения: PRIVATE, PUBLIC, NONE.
  #опциональный параметр
  #по умолчанию: PRIVATE
  #тип - строка
  #используется при создании
  #def_net_type = "NONE"

  #описание
  #опциональный параметр
  #тип - строка
  #используется при создании и обновлении
  #description = "qwerty"

  #id внешней сети
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #ext_net_id = 123

  #ip внешней сети
  #опциональный параметр
  #тип - строка
  #используется при создании
  #ext_ip = "1.1.1.1"

  #список названий pools
  #опциональный параметр
  #тип - массив строк
  #используется при создании и обновлении
  #uniq_pools = ["sep1_poolName1", "sep2_poolName2"]

  #блок для предоставления прав на ресурсную группу
  #опциональный параметр
  #тип - блок прав пользователя
  #используется при создании и обновлении
  #access  {
    #имя юзера предоставляемому права 
    #обязательный параметр при использовании блока
    #тип - строка
    #user = "kasim_baybikov_1@decs3o"

    #тип прав
    #обязательный параметр
    #тип - строка
    #разрешенные значения: "R", "RCX" or "ARCXDU"
    #right = "RCX"
  #}

  #установить сеть по умолчанию
  #опциональный параметр
  #тип - блок конфигурации сети
  #при добавлении блока, удалять его нельзя
  #используется при создании
  #def_net {
    #тип сети
    #обязательный параметр при использовании блока
    #тип - строка
    #net_type = "PUBLIC"

    #id сети
    #идентификатор сегмента сети. Если net_type — PUBLIC, а net_id — 0, 
    #то будет выбран сегмент внешней сети по умолчанию. Если net_type 
    #имеет значение PRIVATE и net_id=0, будет выбран первый vins, определенный для этой ресурсной группы. 
    #в противном случае net_id идентифицирует либо существующий сегмент внешней сети, либо vins.
    #опциональный параметр
    #тип - целое число
    #net_id = 1234
  #}

  #может ли запуститься ВМ, если ресурсов CPU недостаточно
  #опциональный параметр
  #допустимые значения: strict, loose.
  #тип - строка
  #используется при создании и обновлении
  #cpu_allocation_parameter = "loose"

  #cpu allocation ratio
  #опциональный параметр
  #one pCPU = ratio*vCPU (zero or positive value)
  #тип - целое число
  #используется при создании и обновлении
  #cpu_allocation_ratio = 1

  #флаг доступности ресурсной группы
  #опциональный параметр
  #тип - булев
  #используется при создании и обновлении
  #enable = true

  #флаг для восстановления удаленной ресурсной группы
  #опциональный параметр
  #тип - булев
  #используется при обновлении
  #restore = false

  #флаг для принудительного удаления ресурсной группы
  #опциональный параметр
  #тип - булев
  #перед удалением следует перевести ресурсную группу в статус disabled, выставив enable = false
  #используется при удалении
  #force = true

  #флаг для удаления ресурсной группы, без возможности восстановления
  #опциональный параметр
  #тип - булев
  #используется при удалении
  #permanently = true

  #доступ к дополнительным функциям управления ВМ
  #опциональный параметр
  #возможные значенния - "hugepages", "numa", "cpupin", "vfnic",  "dpdk, "changemac"
  #тип - массив строк
  #внимание - требуется указывать итоговое желаемое состояние для ресурсной группы (рг), так как поле compute_features не будет автоматически
  #наследоваться от аккаунта, в котором создается рг.
  #используется при создании и обновлении
  #compute_features = ["hugepages", "numa", "cpupin", "vfnic"]

}
```

Данный пример подразумевает, что ранее по тексту tf-файла выполнена корректная инициализация провайдера (подробнее об инициализации Terraform провайдера DECORT см. соответствующий [раздел](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.9.0/04.02-Инициализация-Terraform-провайдера-DECORT.md)). 

После успешного завершения такого вызова _resource_ функции **decort_cb_rg** в переменной `decort_cb_rg.rg` будут сохранены возвращаемые значения. В частности, для получения идентификатора ресурсной группы следует использовать конструкцию `decort_resgroup.rg.rg_id`.
