Функция доступна в версии провайдера 4.7.0 и выше.

_Resource_ функция **decort_cb_dpdknet** служит для управления виртуальными сетевыми сегментами (Virtual Network Segment) в платформе DECORT.

## Аргументы
_Resource_ функция **decort_cb_dpdknet** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| name | string | :heavy_check_mark: | Имя DPDK сети |
| gid | int | :heavy_check_mark: | GRID ID | 
| vlan_id | int | :heavy_check_mark: | ID виртуальной сети для тегирования траффика на интерфейсе для компьюта |
| ovs_bridge | string | :heavy_check_mark: | OVS bridge в котором будут создаваться интерфейсы для компьютов, созданные из этой сети |
| desc | string | :x: | Текстовое описание сети |
| account_access | []int | :x: | Cписок ID аккаунтов, которым может быть выделена сеть в эксклюзивное пользование |
| rg_access | []int | :x: | Cписок ID ресурсных групп, которым может быть выделена сеть в эксклюзивное пользование |
| enabled | bool | :x: | Флаг включения DPDK сети, по умолчанию сеть создается в состоянии disable |

Пользователь облачной платформы задается на стадии инициализации Terraform провайдера DECORT (см. [подробности](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.9.0/04.02-Инициализация-Terraform-провайдера-DECORT.md)).

## Возвращаемые значения
В случае успешного выполнения _resource_ функция **decort_cb_dpdknet** возвращает в указанную при вызове переменную следующие значения:

| Параметр | Тип | Описание |
| --- | --- | --- |
| account_access | []int | Cписок ID аккаунтов, которым может быть выделена сеть в эксклюзивное пользование |
| compute_ids | []int | Cписок компьютов, которые используют данную сеть для своих интерфейсов |
| created_time | int | Время создания |
| desc | string | Текстовое описание сети |
| dpdk_id | int | Идентификатор сети |
| gid | int | Идентификатор площадки (GRID ID) |
| guid | int | GUID ресурса |
| id | string | Идентификатор сети в формате string |
| name | string | Наименование сети |
| ovs_bridge | string | OVS bridge в котором будут создаваться интерфейсы для компьютов, созданные из этой сети |
| rg_access | []int | Cписок ID ресурсных групп, которым может быть выделена сеть в эксклюзивное пользование |
| status | string | Статус сети |
| updated_time | int | Время обновления |
| vlan_id | int | ID виртуальной сети для тегирования траффика на интерфейсе для компьюта |

## Пример использования
Пример вызова _resource_ функции **decort_cb_dpdknet**:

```terraform
resource "decort_cb_dpdknet" "dpdk" {
  #название
  #обязательный параметр
  #тип - строка
  #используется при создании и обновлении
  name = "dpdk-name"

  #gid
  #обязательный параметр
  #тип - целое число
  #используется при создании
  gid = 212

  #vlanid для тегирования трафика на интерфейсе для компьюта
  #обязательный параметр
  #тип - целое число
  #используется при создании и обновлении
  vlan_id = 123

  #ovs bridge в котором будут создаваться интерфейсы для компьютов, созданные из этой сети
  #обязательный параметр
  #тип - строка
  #используется при создании и обновлении
  ovs_bridge = "OVSBridge"

  #описание сети
  #опциональный параметр
  #тип - строка
  #используется при создании и обновлении
  #desc = "description"

  #список id аккаунтов, которым может быть выделена сеть в эксклюзивное пользование
  #опциональный параметр
  #тип - массив целых чисел
  #используется при создании и обновлении
  #account_access = [10,11]

  #список id ресурсных групп, которым может быть выделена сеть в эксклюзивное пользование
  #опциональный параметр
  #тип - массив целых чисел
  #используется при создании и обновлении
  #rg_access = [10,11]

  #флаг доступности сети для проведения с ней операций
  #опциональный параметр
  #по умолчанию - false
  #тип - булев
  #используется при создании и обновлении
  #enabled = true
}

output "test" {
  value = decort_cb_dpdknet.dpdk
}
```

Данный пример подразумевает, что ранее по тексту tf-файла выполнена корректная инициализация провайдера (подробнее об инициализации Terraform провайдера DECORT см. соответствующий [раздел](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.9.0/04.02-Инициализация-Terraform-провайдера-DECORT.md) и [пример](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.9.0/02.-Пример-работы.md)). 

После успешного завершения такого вызова **decort_cb_dpdknet** в переменной `data.decort_cb_dpdknet.dpdk` будут сохранены возвращаемые значения. В частности, для получения идентификатора сети следует использовать конструкцию `data.decort_cb_dpdknet.dpdk.id`
